==> dragon_1.0.0.tar.gz: dragon/R/utils_globals.R <==
## Miscallaneous that need bindings, largely columns in tibbles ------------------------------------------
`Last modified` <- Name <- NULL ## Associated with find_most_recent_date()
adj.p.value <- p.value <- comparison <- conf.high <- conf.low <- estimate <- statistic <- term <- std.error <- NULL
age_check <- overall_max <- max_age <- min_age <- max_age_locality <- min_age_locality <- NULL
age_type <- at_locality <- locality_longname <- mindat_id <- NULL
num_localities <- num_localities_element <- num_localities_mineral <- mineral_id <- mineral_name <- NULL
atomic_mass <- atomic_radius <- pauling <- element_table_group <- element_table_period <- number_of_protons <-  element_metal_type <- element_density <- element_specific_heat <- element_hsab <- NULL
closeness <- network_degree <- network_degree_norm <- cov_pauling <- mean_pauling <- cluster_ID <- NULL
Element <- Mineral <- ima_chemistry <- rruff_chemistry <- NULL
color <- color.background <- color.border <- colour <- shape <- size <- NULL
font.color <- font.face <- font.size <- frame.color <- label.cex <- NULL
mean_font_size <- mean_size <- rescale_cex <- rescale_size <- NULL
element <- element_name <- chemistry_elements <- element_as_redox <- NULL
to <- from <- id <- label <- title <- group <- type <- NULL
element_redox_mineral <- has_element <- element_redox_mineral_sign <- element_redox_network <- NULL
available <- num <- num_nodes <- NULL   # base_element
rd <- ers <- redox <- thesign <- X2 <- X3 <- X4 <- NULL
V1 <- V2 <- x <- y <- contrast <-  NULL
early_age <- late_age <- label_x <- label_y <- eon_era_name <- selected_age_range <- yend <- ymax <- ymin <- NULL

==> dragon_1.1.0.tar.gz: dragon/R/utils_globals.R <==
## Miscellaneous that need bindings, largely columns in tibbles ------------------------------------------
`Last modified` <- Name <- NULL ## Associated with find_most_recent_date()
adj.p.value <- p.value <- comparison <- conf.high <- conf.low <- estimate <- statistic <- term <- std.error <- NULL
age_check <- overall_max <- max_age <- min_age <- max_age_locality <- min_age_locality <- NULL
age_type <- at_locality <- locality_longname <- mindat_id <- NULL
num_localities <- num_localities_element <- num_localities_mineral <- mineral_id <- mineral_name <- NULL
atomic_mass <- atomic_radius <- pauling <- element_table_group <- element_table_period <- number_of_protons <-  element_metal_type <- element_density <- element_specific_heat <- element_hsab <- NULL
closeness <- network_degree <- network_degree_norm <- cov_pauling <- mean_pauling <- w_cov_pauling <- w_mean_pauling <- cluster_ID <- NULL
Element <- Mineral <- ima_chemistry <- rruff_chemistry <- NULL
color <- color.background <- color.border <- colour <- shape <- size <- NULL
font.color <- font.face <- font.size <- frame.color <- label.cex <- NULL
mean_font_size <- mean_size <- rescale_cex <- rescale_size <- NULL
element <- element_name <- chemistry_elements <- element_as_redox <- NULL
to <- from <- id <- label <- title <- group <- type <- both <- NULL
element_redox_mineral <- has_element <- element_redox_mineral_sign <- element_redox_network <- NULL
available <- num <- num_nodes <- NULL   # base_element
rd <- ers <- redox <- thesign <- X2 <- X3 <- X4 <- NULL
V1 <- V2 <- x <- y <- contrast <-  NULL
early_age <- late_age <- label_x <- label_y <- eon_era_name <- selected_age_range <- yend <- ymax <- ymin <- NULL
